==> app-model-0.1.0.tar.gz: app-model-0.1.0/CHANGELOG.md <==
# Changelog

## [0.1.0](https://github.com/napari/app-model/tree/0.1.0) (2022-10-10)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.9...0.1.0)

**Fixed bugs:**

- fix: properly detect when ctrl and meta swapped on mac [\#64](https://github.com/napari/app-model/pull/64) ([kne42](https://github.com/kne42))
- fix various bugs [\#63](https://github.com/napari/app-model/pull/63) ([kne42](https://github.com/kne42))

**Merged pull requests:**

- feat: convert keybinding to normal class [\#68](https://github.com/napari/app-model/pull/68) ([kne42](https://github.com/kne42))
- ci\(dependabot\): bump styfle/cancel-workflow-action from 0.10.0 to 0.10.1 [\#66](https://github.com/napari/app-model/pull/66) ([dependabot[bot]](https://github.com/apps/dependabot))

## [v0.0.9](https://github.com/napari/app-model/tree/v0.0.9) (2022-08-26)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.8...v0.0.9)

**Implemented enhancements:**

- feat: eval expr when creating menus [\#61](https://github.com/napari/app-model/pull/61) ([tlambert03](https://github.com/tlambert03))

**Documentation:**

- docs: fix a few typos in docs [\#60](https://github.com/napari/app-model/pull/60) ([alisterburt](https://github.com/alisterburt))

## [v0.0.8](https://github.com/napari/app-model/tree/v0.0.8) (2022-08-21)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.7...v0.0.8)

**Implemented enhancements:**

- feat: add ToggleRule for toggleable Actions [\#59](https://github.com/napari/app-model/pull/59) ([tlambert03](https://github.com/tlambert03))

**Tests & CI:**

- ci: add napari tests [\#57](https://github.com/napari/app-model/pull/57) ([tlambert03](https://github.com/tlambert03))

**Merged pull requests:**

- refactor: switch to extra ignore [\#58](https://github.com/napari/app-model/pull/58) ([tlambert03](https://github.com/tlambert03))

## [v0.0.7](https://github.com/napari/app-model/tree/v0.0.7) (2022-07-24)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.6...v0.0.7)

**Merged pull requests:**

- build: relax runtime typing extensions dependency [\#49](https://github.com/napari/app-model/pull/49) ([tlambert03](https://github.com/tlambert03))

## [v0.0.6](https://github.com/napari/app-model/tree/v0.0.6) (2022-07-24)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.5...v0.0.6)

**Implemented enhancements:**

- feat: add get\_app class method to Application [\#48](https://github.com/napari/app-model/pull/48) ([tlambert03](https://github.com/tlambert03))

## [v0.0.5](https://github.com/napari/app-model/tree/v0.0.5) (2022-07-23)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.4...v0.0.5)

**Implemented enhancements:**

- test: more test coverage [\#46](https://github.com/napari/app-model/pull/46) ([tlambert03](https://github.com/tlambert03))
- feat: add register\_actions [\#45](https://github.com/napari/app-model/pull/45) ([tlambert03](https://github.com/tlambert03))
- fix: small getitem fixes for napari [\#44](https://github.com/napari/app-model/pull/44) ([tlambert03](https://github.com/tlambert03))
- feat: qt key conversion helpers [\#43](https://github.com/napari/app-model/pull/43) ([tlambert03](https://github.com/tlambert03))

**Fixed bugs:**

- fix: fix sorting when group is None [\#42](https://github.com/napari/app-model/pull/42) ([tlambert03](https://github.com/tlambert03))

**Tests & CI:**

- tests: more qtest coverage [\#47](https://github.com/napari/app-model/pull/47) ([tlambert03](https://github.com/tlambert03))

## [v0.0.4](https://github.com/napari/app-model/tree/v0.0.4) (2022-07-16)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.3...v0.0.4)

**Implemented enhancements:**

- feat: add toggled to command [\#41](https://github.com/napari/app-model/pull/41) ([tlambert03](https://github.com/tlambert03))
- feat: raise\_synchronous option, and expose app classes [\#40](https://github.com/napari/app-model/pull/40) ([tlambert03](https://github.com/tlambert03))

## [v0.0.3](https://github.com/napari/app-model/tree/v0.0.3) (2022-07-14)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.2...v0.0.3)

**Merged pull requests:**

- fix: expression hashing and repr [\#39](https://github.com/napari/app-model/pull/39) ([tlambert03](https://github.com/tlambert03))

## [v0.0.2](https://github.com/napari/app-model/tree/v0.0.2) (2022-07-13)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.1...v0.0.2)

**Merged pull requests:**

- chore: move tlambert03/app-model to napari [\#38](https://github.com/napari/app-model/pull/38) ([tlambert03](https://github.com/tlambert03))
- fix: allow older qtpy [\#37](https://github.com/napari/app-model/pull/37) ([tlambert03](https://github.com/tlambert03))
- docs: Add Documentation [\#36](https://github.com/napari/app-model/pull/36) ([tlambert03](https://github.com/tlambert03))
- feat: cache qactions \[wip\] [\#35](https://github.com/napari/app-model/pull/35) ([tlambert03](https://github.com/tlambert03))
- feat: updating demo [\#34](https://github.com/napari/app-model/pull/34) ([tlambert03](https://github.com/tlambert03))
- build: pin min typing extensions [\#33](https://github.com/napari/app-model/pull/33) ([tlambert03](https://github.com/tlambert03))
- feat: add standard keybindings [\#32](https://github.com/napari/app-model/pull/32) ([tlambert03](https://github.com/tlambert03))
- feat: frozen models [\#31](https://github.com/napari/app-model/pull/31) ([tlambert03](https://github.com/tlambert03))
- refactor: restrict to only one command per id [\#30](https://github.com/napari/app-model/pull/30) ([tlambert03](https://github.com/tlambert03))

## [v0.0.1](https://github.com/napari/app-model/tree/v0.0.1) (2022-07-06)

[Full Changelog](https://github.com/napari/app-model/compare/3a1e61cc7b0b249a9f2e3fce9cfa6cf6b766cb2a...v0.0.1)

**Merged pull requests:**

- refactor: a number of fixes [\#26](https://github.com/napari/app-model/pull/26) ([tlambert03](https://github.com/tlambert03))
- feat: demo app [\#24](https://github.com/napari/app-model/pull/24) ([tlambert03](https://github.com/tlambert03))
- test: fix pre-test [\#23](https://github.com/napari/app-model/pull/23) ([tlambert03](https://github.com/tlambert03))
- build: add py.typed [\#22](https://github.com/napari/app-model/pull/22) ([tlambert03](https://github.com/tlambert03))
- feat: add injection model to app [\#21](https://github.com/napari/app-model/pull/21) ([tlambert03](https://github.com/tlambert03))
- feat: allow callbacks as strings [\#18](https://github.com/napari/app-model/pull/18) ([tlambert03](https://github.com/tlambert03))
- refactor: create backend folder [\#17](https://github.com/napari/app-model/pull/17) ([tlambert03](https://github.com/tlambert03))
- feat: Keybindings! [\#16](https://github.com/napari/app-model/pull/16) ([tlambert03](https://github.com/tlambert03))
- feat: more qt support, submenus, etc [\#11](https://github.com/napari/app-model/pull/11) ([tlambert03](https://github.com/tlambert03))
- feat: Add qt module [\#10](https://github.com/napari/app-model/pull/10) ([tlambert03](https://github.com/tlambert03))
- feat: combine app model [\#9](https://github.com/napari/app-model/pull/9) ([tlambert03](https://github.com/tlambert03))
- test: more test coverage, organization, and documentation [\#7](https://github.com/napari/app-model/pull/7) ([tlambert03](https://github.com/tlambert03))
- fix: Fix windows keybindings tests [\#5](https://github.com/napari/app-model/pull/5) ([tlambert03](https://github.com/tlambert03))
- ci\(dependabot\): bump codecov/codecov-action from 2 to 3 [\#2](https://github.com/napari/app-model/pull/2) ([dependabot[bot]](https://github.com/apps/dependabot))
- ci\(dependabot\): bump styfle/cancel-workflow-action from 0.9.1 to 0.10.0 [\#1](https://github.com/napari/app-model/pull/1) ([dependabot[bot]](https://github.com/apps/dependabot))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*

==> app-model-0.1.1.tar.gz: app-model-0.1.1/CHANGELOG.md <==
# Changelog

## [v0.1.1](https://github.com/napari/app-model/tree/v0.1.1) (2022-11-10)

[Full Changelog](https://github.com/napari/app-model/compare/v0.1.0...v0.1.1)

**Implemented enhancements:**

- feat: support python 3.11 [\#77](https://github.com/napari/app-model/pull/77) ([tlambert03](https://github.com/tlambert03))

**Fixed bugs:**

- fix: fix unsupported operand [\#76](https://github.com/napari/app-model/pull/76) ([tlambert03](https://github.com/tlambert03))

**Merged pull requests:**

- refactor: Use a dict \(as an ordered set\) instead of a list for menus registry [\#74](https://github.com/napari/app-model/pull/74) ([aganders3](https://github.com/aganders3))
- ci\(dependabot\): bump styfle/cancel-workflow-action from 0.10.1 to 0.11.0 [\#72](https://github.com/napari/app-model/pull/72) ([dependabot[bot]](https://github.com/apps/dependabot))

## [v0.1.0](https://github.com/napari/app-model/tree/v0.1.0) (2022-10-10)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.9...v0.1.0)

**Fixed bugs:**

- fix: properly detect when ctrl and meta swapped on mac [\#64](https://github.com/napari/app-model/pull/64) ([kne42](https://github.com/kne42))
- fix various bugs [\#63](https://github.com/napari/app-model/pull/63) ([kne42](https://github.com/kne42))

**Merged pull requests:**

- chore: changelog v0.1.0 [\#69](https://github.com/napari/app-model/pull/69) ([tlambert03](https://github.com/tlambert03))
- feat: convert keybinding to normal class [\#68](https://github.com/napari/app-model/pull/68) ([kne42](https://github.com/kne42))
- ci\(dependabot\): bump styfle/cancel-workflow-action from 0.10.0 to 0.10.1 [\#66](https://github.com/napari/app-model/pull/66) ([dependabot[bot]](https://github.com/apps/dependabot))

## [v0.0.9](https://github.com/napari/app-model/tree/v0.0.9) (2022-08-26)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.8...v0.0.9)

**Implemented enhancements:**

- feat: eval expr when creating menus [\#61](https://github.com/napari/app-model/pull/61) ([tlambert03](https://github.com/tlambert03))

**Documentation:**

- docs: fix a few typos in docs [\#60](https://github.com/napari/app-model/pull/60) ([alisterburt](https://github.com/alisterburt))

## [v0.0.8](https://github.com/napari/app-model/tree/v0.0.8) (2022-08-21)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.7...v0.0.8)

**Implemented enhancements:**

- feat: add ToggleRule for toggleable Actions [\#59](https://github.com/napari/app-model/pull/59) ([tlambert03](https://github.com/tlambert03))

**Tests & CI:**

- ci: add napari tests [\#57](https://github.com/napari/app-model/pull/57) ([tlambert03](https://github.com/tlambert03))

**Merged pull requests:**

- refactor: switch to extra ignore [\#58](https://github.com/napari/app-model/pull/58) ([tlambert03](https://github.com/tlambert03))

## [v0.0.7](https://github.com/napari/app-model/tree/v0.0.7) (2022-07-24)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.6...v0.0.7)

**Merged pull requests:**

- build: relax runtime typing extensions dependency [\#49](https://github.com/napari/app-model/pull/49) ([tlambert03](https://github.com/tlambert03))

## [v0.0.6](https://github.com/napari/app-model/tree/v0.0.6) (2022-07-24)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.5...v0.0.6)

**Implemented enhancements:**

- feat: add get\_app class method to Application [\#48](https://github.com/napari/app-model/pull/48) ([tlambert03](https://github.com/tlambert03))

## [v0.0.5](https://github.com/napari/app-model/tree/v0.0.5) (2022-07-23)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.4...v0.0.5)

**Implemented enhancements:**

- test: more test coverage [\#46](https://github.com/napari/app-model/pull/46) ([tlambert03](https://github.com/tlambert03))
- feat: add register\_actions [\#45](https://github.com/napari/app-model/pull/45) ([tlambert03](https://github.com/tlambert03))
- fix: small getitem fixes for napari [\#44](https://github.com/napari/app-model/pull/44) ([tlambert03](https://github.com/tlambert03))
- feat: qt key conversion helpers [\#43](https://github.com/napari/app-model/pull/43) ([tlambert03](https://github.com/tlambert03))

**Fixed bugs:**

- fix: fix sorting when group is None [\#42](https://github.com/napari/app-model/pull/42) ([tlambert03](https://github.com/tlambert03))

**Tests & CI:**

- tests: more qtest coverage [\#47](https://github.com/napari/app-model/pull/47) ([tlambert03](https://github.com/tlambert03))

## [v0.0.4](https://github.com/napari/app-model/tree/v0.0.4) (2022-07-16)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.3...v0.0.4)

**Implemented enhancements:**

- feat: add toggled to command [\#41](https://github.com/napari/app-model/pull/41) ([tlambert03](https://github.com/tlambert03))
- feat: raise\_synchronous option, and expose app classes [\#40](https://github.com/napari/app-model/pull/40) ([tlambert03](https://github.com/tlambert03))

## [v0.0.3](https://github.com/napari/app-model/tree/v0.0.3) (2022-07-14)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.2...v0.0.3)

**Merged pull requests:**

- fix: expression hashing and repr [\#39](https://github.com/napari/app-model/pull/39) ([tlambert03](https://github.com/tlambert03))

## [v0.0.2](https://github.com/napari/app-model/tree/v0.0.2) (2022-07-13)

[Full Changelog](https://github.com/napari/app-model/compare/v0.0.1...v0.0.2)

**Merged pull requests:**

- chore: move tlambert03/app-model to napari [\#38](https://github.com/napari/app-model/pull/38) ([tlambert03](https://github.com/tlambert03))
- fix: allow older qtpy [\#37](https://github.com/napari/app-model/pull/37) ([tlambert03](https://github.com/tlambert03))
- docs: Add Documentation [\#36](https://github.com/napari/app-model/pull/36) ([tlambert03](https://github.com/tlambert03))
- feat: cache qactions \[wip\] [\#35](https://github.com/napari/app-model/pull/35) ([tlambert03](https://github.com/tlambert03))
- feat: updating demo [\#34](https://github.com/napari/app-model/pull/34) ([tlambert03](https://github.com/tlambert03))
- build: pin min typing extensions [\#33](https://github.com/napari/app-model/pull/33) ([tlambert03](https://github.com/tlambert03))
- feat: add standard keybindings [\#32](https://github.com/napari/app-model/pull/32) ([tlambert03](https://github.com/tlambert03))
- feat: frozen models [\#31](https://github.com/napari/app-model/pull/31) ([tlambert03](https://github.com/tlambert03))
- refactor: restrict to only one command per id [\#30](https://github.com/napari/app-model/pull/30) ([tlambert03](https://github.com/tlambert03))

## [v0.0.1](https://github.com/napari/app-model/tree/v0.0.1) (2022-07-06)

[Full Changelog](https://github.com/napari/app-model/compare/3a1e61cc7b0b249a9f2e3fce9cfa6cf6b766cb2a...v0.0.1)

**Merged pull requests:**

- refactor: a number of fixes [\#26](https://github.com/napari/app-model/pull/26) ([tlambert03](https://github.com/tlambert03))
- feat: demo app [\#24](https://github.com/napari/app-model/pull/24) ([tlambert03](https://github.com/tlambert03))
- test: fix pre-test [\#23](https://github.com/napari/app-model/pull/23) ([tlambert03](https://github.com/tlambert03))
- build: add py.typed [\#22](https://github.com/napari/app-model/pull/22) ([tlambert03](https://github.com/tlambert03))
- feat: add injection model to app [\#21](https://github.com/napari/app-model/pull/21) ([tlambert03](https://github.com/tlambert03))
- feat: allow callbacks as strings [\#18](https://github.com/napari/app-model/pull/18) ([tlambert03](https://github.com/tlambert03))
- refactor: create backend folder [\#17](https://github.com/napari/app-model/pull/17) ([tlambert03](https://github.com/tlambert03))
- feat: Keybindings! [\#16](https://github.com/napari/app-model/pull/16) ([tlambert03](https://github.com/tlambert03))
- feat: more qt support, submenus, etc [\#11](https://github.com/napari/app-model/pull/11) ([tlambert03](https://github.com/tlambert03))
- feat: Add qt module [\#10](https://github.com/napari/app-model/pull/10) ([tlambert03](https://github.com/tlambert03))
- feat: combine app model [\#9](https://github.com/napari/app-model/pull/9) ([tlambert03](https://github.com/tlambert03))
- test: more test coverage, organization, and documentation [\#7](https://github.com/napari/app-model/pull/7) ([tlambert03](https://github.com/tlambert03))
- fix: Fix windows keybindings tests [\#5](https://github.com/napari/app-model/pull/5) ([tlambert03](https://github.com/tlambert03))
- ci\(dependabot\): bump codecov/codecov-action from 2 to 3 [\#2](https://github.com/napari/app-model/pull/2) ([dependabot[bot]](https://github.com/apps/dependabot))
- ci\(dependabot\): bump styfle/cancel-workflow-action from 0.9.1 to 0.10.0 [\#1](https://github.com/napari/app-model/pull/1) ([dependabot[bot]](https://github.com/apps/dependabot))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
